ansible_runner.display_callback.minimal — ansible-runner 1.0.4 documentation

# Source code for ansible_runner.display_callback.minimal

    # Copyright (c) 2016 Ansible by Red Hat, Inc.
    #
    # This file is part of Ansible Tower, but depends on code imported from Ansible.
    #
    # Ansible is free software: you can redistribute it and/or modify
    # it under the terms of the GNU General Public License as published by
    # the Free Software Foundation, either version 3 of the License, or
    # (at your option) any later version.
    #
    # Ansible is distributed in the hope that it will be useful,
    # but WITHOUT ANY WARRANTY; without even the implied warranty of
    # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    # GNU General Public License for more details.
    #
    # You should have received a copy of the GNU General Public License
    # along with Ansible.  If not, see <http://www.gnu.org/licenses/>.

    from __future__ import (absolute_import, division, print_function)

    # Python
    import os

    # Ansible
    import ansible

    # Because of the way Ansible loads plugins, it's not possible to import
    # ansible.plugins.callback.minimal when being loaded as the minimal plugin. Ugh.
    minimal_plugin = os.path.join(os.path.dirname(ansible.__file__), 'plugins', 'callback', 'minimal.py')
    exec(compile(open(minimal_plugin, "rb").read(), minimal_plugin, 'exec'))